config = {
    # Vendor token and name are listed at the top of
    # https://<your domain>.exosite.com/admin/managemodels
    # (Vendor token is also available on the domain admin home page)
    'vendorname': 'weaver',
    'vendortoken': '30c8b8bd3ec721ead0c447365c7232b870db76f1',
    # CIK of parent of clonecik client. In the case of Portals,
    # this is the CIK of the portal. It can be found in your portal under
    # Account > Portals
    # Look for: Key: 123abc...
    'portalcik': 'baa1f6617dd7ea8b6200648251d97926d972b75c',
    'cloneportalcik': 'baa1f6617dd7ea8b6200648251d97926d972b75c'
}
